@@ -18,7 +18,7 @@ class BenchmarkTestCase(_testlib._BaseTestCase):
     def _base_insertion_benchmark(self, num_nodes, num_roots, commit_once):
         import random
         MAX_DEPTH = 20
-        node_ids = [list() for x in xrange(MAX_DEPTH)]
+        node_ids = [list() for x in range(MAX_DEPTH)]
         def random_parent_id():
             depth = MAX_DEPTH * 1.5625 * (random.random() - 0.2) ** 2
             depth = int(depth)
@@ -27,13 +27,13 @@ class BenchmarkTestCase(_testlib._BaseTestCase):
             return random.choice(node_ids[depth])
 
         start = time()
-        for x in xrange(num_roots):
+        for x in range(num_roots):
             root = Cls()
             self.sess.add(root)
             self.sess.flush()
             self.sess.commit()
             node_ids[0].append(root.id)
-        for x in xrange(num_nodes - num_roots):
+        for x in range(num_nodes - num_roots):
             parent_id = random_parent_id()
             node = Cls(parent_id=parent_id)
             self.sess.add(node)
@@ -50,29 +50,29 @@ class BenchmarkTestCase(_testlib._BaseTestCase):
         elapsed = time() - start
         transactions = commit_once and "all in one transaction" \
                                    or "each in self transaction"
-        print "%d insertions in %.2f seconds %s " \
+        print("%d insertions in %.2f seconds %s " \
               "(%.2f insertions per second)" % \
-              (num_nodes, elapsed, transactions, num_nodes / elapsed)
+              (num_nodes, elapsed, transactions, num_nodes / elapsed))
 
     def _descendants_benchmark(self, num_passes):
         total_children = 0
         total_nodes = self.sess.query(Cls).count()
         start = time()
-        for x in xrange(num_passes):
+        for x in range(num_passes):
             for node in self.sess.query(Cls):
                 total_children += len(node.mp.query_descendants().all())
         elapsed = time() - start
         queries = num_passes * total_nodes
         average_children = float(total_children) / queries
-        print "%d queries in %.2f seconds (%.2f queries per second), " \
+        print("%d queries in %.2f seconds (%.2f queries per second), " \
               "average of %.2f descendants in each node." % \
-              (queries, elapsed, queries / elapsed, average_children)
+              (queries, elapsed, queries / elapsed, average_children))
 
     def test_benchmark(self):
         if not os.environ.get('BENCHMARK'):
-            print "NB: benchmarks skipped."
+            print("NB: benchmarks skipped.")
             return
-        print "BENCHMARKING..."
+        print("BENCHMARKING...")
         self._base_insertion_benchmark(
             commit_once=False, num_nodes=1000, num_roots=10
         )
